pub struct Hash { /* private fields */ }Expand description
A finalized BLAKE2 hash, with constant-time equality.
Implementations
Sourceimpl Hash
impl Hash
Sourcepub fn as_bytes(&self) -> &[u8] ⓘ
pub fn as_bytes(&self) -> &[u8] ⓘ
Convert the hash to a byte slice. Note that if you’re using BLAKE2 as a MAC, you need
constant time equality, which &[u8] doesn’t provide.
Sourcepub fn as_array(&self) -> &[u8; 32]
pub fn as_array(&self) -> &[u8; 32]
Convert the hash to a byte array. Note that if you’re using BLAKE2 as a
MAC, you need constant time equality, which arrays don’t provide. This
panics in debug mode if the length of the hash isn’t OUTBYTES.
Sourcepub fn to_hex(&self) -> ArrayString<{ _ }>
pub fn to_hex(&self) -> ArrayString<{ _ }>
Convert the hash to a lowercase hexadecimal
ArrayString.